#include "boot/Init.h"
#include "Log.h"
#include "arch/CPU.h"
#include "arch/Serial.h"
#include "boot/bootboot.h"
#include "memory/MemoryManager.h"
#include "video/Framebuffer.h"
#include <String.h>

extern BOOTBOOT bootboot;

void Init::check_magic()
{
    if (memcmp(bootboot.magic, BOOTBOOT_MAGIC, 4))
    {
        Serial::println("ERROR: Invalid magic value from bootloader");
        for (;;)
            ;
    }
}

void Init::early_init()
{
    CPU::disable_interrupts();

    Framebuffer::init();

    setup_log(log_debug_enabled(), log_serial_enabled(), true);

    MemoryManager::init();

    CPU::platform_init();

    MemoryManager::protect_kernel_sections().release_value();
}